@@ -4,33 +4,34 @@ module Dcl_Thermo_Graph
   use Thermo_Function
   use Statistics
   use dcl
+  use Basis
 
 contains
 
 subroutine SkewT( title, slope, t_int, p_int,  &
   &               sondeT, sondeP, sondeQV,  &
-  &               sondeZ, viewx_int, viewy_int, undef, no_frame )
+  &               sondeZ, viewx_int, viewy_int, undef, no_frame, refh )
 ! skew-T 롼
 ! ȽļΥȥϤ٤ height  temperature Ǹ.
   use Thermo_Const
-  use Thermo_Function
-  use Statistics
-  use Dcl
   implicit none
   character(*), intent(in) :: title  ! ɽΥȥ
   real, intent(in) :: slope  ! skewT η
   real, intent(in) :: t_int(2)  ! ʲ١ˤξü [K]
                       ! t_int(1)=tmin, t_int(2)=tmax
-  real, intent(in) :: p_int(2)  ! ʵˤξü [Pa]
+  real, intent(in) :: p_int(2)  ! ļʵˤξü [Pa]
                       ! p_int(1)=pmin, p_int(2)=pmax
+                      ! sondeZ Ϳ, ΰ
+                      ! p_int(1)=zmin, p_int(2)=zmax .
   real, intent(in), dimension(:) :: sondeT  ! Ǥβ [K]
   real, intent(in), dimension(size(sondeT)) :: sondeP  ! Ǥε [Pa]
   real, intent(in), dimension(size(sondeT)) :: sondeQV  ! Ǥκ [kg/kg]
   real, intent(in), dimension(size(sondeT)), optional :: sondeZ  ! Ǥι [m]
   ! sondeP : logP ǽļȤ. ΤȤ, pmin, pmax, sondeP Ϥ٤
-  !               Pa ñ̤ǤȤ뤳.
+  !           Pa ñ̤ǤȤ뤳.
   ! sondeZ(optional) : geometric z ǽļȤ.
-  !              ΤȤ, pmin, pmax ϵǤϤʤ, 褷 [m] κǾͤͿ.
+  !                    ΤȤ, pmin, pmax ϵǤϤʤ, 
+  !                    褷 [m] κǾͤͿ.
   ! z=-logP δطˤʤ뤬, ǽΤ, ѼԤ
   ! ˤ, min Ϻ, max Ϻͤ OK.
   ! ǥեȤǤ, ǽļ.
@@ -43,6 +44,7 @@ subroutine SkewT( title, slope, t_int, p_int,  &
   logical, intent(in), optional :: no_frame  ! NewFrame ƤФʤ
                                    ! .false. = Ƥ. .true. = ƤФ NewFig.
                                    ! ǥեȤ .false.
+  real, intent(in), optional :: refh  ! reference pressure (or height in sondeZ) of moist adiabat
 !-- ʾ, 
   real :: tmin  ! ʲ١ˤκ [K]
   real :: tmax  ! ʲ١ˤκǹ [K]
@@ -56,26 +58,31 @@ subroutine SkewT( title, slope, t_int, p_int,  &
   real :: vymax  ! viewport  xmin.
 !-- ʾ, ֤ѿ
   integer, parameter :: nx=100, ny=100
+  real, dimension(nx) :: septc, tempc
   real, dimension(nx,ny) :: temp, pt, qvs, spt
-  real, dimension(size(sondeT)) :: sondedT, sondedP, sondedTD
+  real, dimension(size(sondeT)) :: sondedT, sondedP, sondedTD, sondedSEPT
+  real, dimension(size(sondeT)) :: sondeRP
   real, dimension(nx) :: tempd
   real, dimension(ny) :: p, z
-  integer :: i, j, k, nt, i_z, i_p
+  integer :: i, j, k, nt, i_z, i_p, i_sept
   real :: pdmax, pdmin
-  real :: dp, dpd, dt
+  real :: dp, dt
   real :: undeff
   real :: slope_param, dz
-  logical :: heiopt_z, no_frame_flag
+  real :: refp, reft, refsept
+  logical :: heiopt_z, no_frame_flag, moist_flag
 
   heiopt_z=.false.
   nt=size(sondeT)
 
   if(present(undef))then
      undeff=undef
+  else
+     undeff=-999.0
   end if
 
 !-- DCL 
-  call SGLSET('LCLIP',.true.)  ! åԥ󥰽
+!  call SGLSET('LCLIP',.true.)  ! åԥ󥰽
   call DclSetParm( 'ENABLE_CONTOUR_MESSAGE', .false. )
 
 !-- ʹ, ץ
@@ -101,6 +108,16 @@ subroutine SkewT( title, slope, t_int, p_int,  &
      no_frame_flag=.false.
   end if
 
+!-- reverse pressure for interpo_search_1d
+
+  do i=1,nt
+     if(sondeP(i)/=undeff)then
+        sondeRP(i)=-sondeP(i)
+     else
+        sondeRP(i)=undeff
+     end if
+  end do
+
 !-- ֤ѿ֤
   pmin=p_int(1)
   pmax=p_int(2)
@@ -129,14 +146,36 @@ subroutine SkewT( title, slope, t_int, p_int,  &
         call interpo_search_1d( sondeZ, z(i), i_z )
         call interpolation_1d( z(i_z:i_z+1), sondeP(i_z:i_z+1), z(i), p(i) )
      end do
+
+     pdmin=zmin
+     pdmax=zmax
   else
      dp=(pmax-pmin)/(ny-1)
      p=(/((pmax-dp*(i-1)),i=1,ny)/)
+     pdmin=pmin*1.0e-2
+     pdmax=pmax*1.0e-2
   end if
 
-  pdmin=pmin*1.0e-2
-  pdmax=pmax*1.0e-2
-  dpd=(pdmax-pdmin)/(ny-1)
+!-- drawing moist adiabat line (option)
+
+  if(present(refh))then
+     moist_flag=.true.
+     if(heiopt_z.eqv..true.)then
+        call interpo_search_1d( sondeZ, refh, i_z )
+        call interpolation_1d( sondeZ(i_z:i_z+1), sondeP(i_z:i_z+1),  &
+  &                            refh, refp )
+        call interpolation_1d( sondeZ(i_z:i_z+1), sondeT(i_z:i_z+1),  &
+  &                            refh, reft )
+        refsept=thetaes_Bolton( reft, refp )
+     else
+        call interpo_search_1d( sondeRP, -refh, i_z )
+        call interpolation_1d( sondeRP(i_z:i_z+1), sondeT(i_z:i_z+1),  &
+  &                            -refh, reft )
+        refsept=thetaes_Bolton( reft, refh )
+     end if
+  else
+     moist_flag=.false.
+  end if
 
 !-- ƶη׻
   do j=1,ny
@@ -156,7 +195,36 @@ subroutine SkewT( title, slope, t_int, p_int,  &
      if(sondeT(j)==undeff.or.sondeP(j)==undeff.or.sondeQV(j)==undeff)then
         sondedT(j)=undeff
         sondedTD(j)=undeff
+        sondedSEPT(j)=undeff
      else
+        !-- calculating sounding thetaes from here
+
+        if(moist_flag.eqv..true.)then
+           do i=1,nx
+              if(heiopt_z.eqv..true.)then
+                 tempc(i)=tmin+dt*real(i-1)-slope*sondeZ(j)*slope_param
+              else
+                 tempc(i)=tmin+dt*real(i-1)+slope*log(sondeP(j)/p0)
+              end if
+              septc(i)=thetaes_Bolton( tempc(i), sondeP(j) )
+           end do
+           call interpo_search_1d( septc(:), refsept, i_sept )
+           if(i_sept>0)then
+              call interpolation_1d( septc(i_sept:i_sept+1),  &
+  &                                  tempc(i_sept:i_sept+1),  &
+  &                                  refsept, sondedSEPT(j) )
+           end if
+           !-- reversing slope because drawing by line
+           if(heiopt_z.eqv..true.)then
+              sondedSEPT(j)=sondedSEPT(j)+slope*sondeZ(j)*slope_param
+           else
+              sondedSEPT(j)=sondedSEPT(j)-slope*log(sondeP(j)/p0)
+           end if
+        else
+           sondedSEPT(j)=undeff
+        end if
+        !-- calculating sounding thetaes to here
+
         if(heiopt_z.eqv..true.)then
            sondedT(j)=sondeT(j)+slope*sondeZ(j)*slope_param  ! 2000 ǳ뺬Ϥʤ.
            sondedTD(j)=es_TD(qvP_2_e(sondeQV(j),sondeP(j)))+slope*sondeZ(j)*slope_param
@@ -178,256 +246,6 @@ subroutine SkewT( title, slope, t_int, p_int,  &
      call DclNewFrame
   end if
 
-  call DclScalingPoint( sondedT, sondedP )
-  if(heiopt_z.eqv..true.)then
-     call DclSetTransNumber( 1 )
-     call DclSetWindow( tmin, tmax, zmin, zmax )
-  else
-     call DclSetTransNumber( 2 )
-     call DclSetWindow( tmin, tmax, pdmax, pdmin )
-  end if
-  call DclSetViewPort( vxmin, vxmax, vymin, vymax )
-  call DclSetTransFunction
-
-  if(heiopt_z.eqv..true.)then
-     call DclSetTitle( 'Temperature', 'height', '', '' )
-  else
-     call DclSetTitle( 'Temperature', 'pressure', '', '' )
-  end if
-
-  call DclDrawScaledAxis
-
-  call UDISET('INDXMJ', 31)
-  call UDISET('INDXMN', 31)
-  call DclDrawContour( temp )
-  call UDISET('INDXMJ', 22)
-  call UDISET('INDXMN', 22)
-  call DclDrawContour( pt )
-  call UDISET('INDXMJ', 13)
-  call UDISET('INDXMN', 13)
-  call DclDrawContour( spt )
-  call UDISET('INDXMJ', 1)
-  call DclDrawContour( qvs )
-  call DclDrawLine( sondedT, sondedP, index=43 )
-  call DclDrawLine( sondedTD, sondedP, index=43, type=2 )
-  call DclDrawTitle( 't', trim(title) )
-
-end subroutine
-
-!-----------------------------------------------
-
-subroutine SkewT_vec( title, slope, t_int, p_int,  &
-  &                   sondeT, sondeP, sondeQV,  &
-  &                   sondeU, sondeV, sondeZ,  &
-  &                   viewx_int, viewy_int, vx, undef, no_frame )
-! skew-T  + vector ޤ롼
-! ȽļΥȥϤ٤ height  temperature Ǹ.
-  use Thermo_Const
-  use Thermo_Function
-  use Statistics
-  use Dcl
-  implicit none
-  character(*), intent(in) :: title  ! ɽΥȥ
-  real, intent(in) :: slope  ! skewT η
-  real, intent(in) :: t_int(2)  ! ʲ١ˤξü [K]
-                      ! t_int(1)=tmin, t_int(2)=tmax
-  real, intent(in) :: p_int(2)  ! ʵˤξü [Pa]
-                      ! p_int(1)=pmin, p_int(2)=pmax
-  real, intent(in), dimension(:) :: sondeT  ! Ǥβ [K]
-  real, intent(in), dimension(size(sondeT)) :: sondeP  ! Ǥε [Pa]
-  real, intent(in), dimension(size(sondeT)) :: sondeQV  ! Ǥκ [kg/kg]
-  real, intent(in), dimension(size(sondeT)) :: sondeU  ! Ǥ [m/s]
-  real, intent(in), dimension(size(sondeT)) :: sondeV  ! Ǥ [m/s]
-  real, intent(in), dimension(size(sondeT)), optional :: sondeZ  ! Ǥι [m]
-  ! sondeP : logP ǽļȤ. ΤȤ, pmin, pmax, sondeP Ϥ٤
-  !               Pa ñ̤ǤȤ뤳.
-  ! sondeZ(optional) : geometric z ǽļȤ.
-  !              ΤȤ, pmin, pmax ϵǤϤʤ, 褷 [m] κǾͤͿ.
-  ! z=-logP δطˤʤ뤬, ǽΤ, ѼԤ
-  ! ˤ, min Ϻ, max Ϻͤ OK.
-  ! ǥեȤǤ, ǽļ.
-  real, intent(in), optional :: viewx_int(2)  ! viewport  x ξü.
-                                ! viewx_int(1)=viewxmin, viewx_int(2)=viewxmax
-  real, intent(in), optional :: viewy_int(2)  ! viewport  y ξü.
-                                ! viewy_int(1)=viewymin, viewy_int(2)=viewymax
-  ! ǥեȤ, (0.25, 0.7, 0.2, 0.8) Ǹ.
-  integer, intent(in), optional :: vx  ! ٥ȥδְʻҿ.
-  ! ְ, Ϥ˴ؤʻҾ֤.
-  ! ǥեȤ 10 ʻ
-  real, intent(in), optional :: undef  ! ̤, ǥեȤǤꤷʤ.
-  logical, intent(in), optional :: no_frame  ! NewFrame ƤФʤ
-                                   ! .false. = Ƥ. .true. = ƤФ NewFig.
-                                   ! ǥեȤ .false.
-!-- ʾ, 
-  real :: tmin  ! ʲ١ˤκ [K]
-  real :: tmax  ! ʲ١ˤκǹ [K]
-  real :: pmin  ! ļʵˤκ [Pa]
-  real :: pmax  ! ļʵˤκǹ [Pa]
-  real :: vxmin  ! viewport  xmin.
-  real :: vxmax  ! viewport  xmin.
-  real :: vymin  ! viewport  xmin.
-  real :: vymax  ! viewport  xmin.
-!-- ʾ, ֤ѿ
-  integer, parameter :: nx=100, ny=100
-  real, dimension(nx,ny) :: temp, pt, qvs, spt
-  real, dimension(size(sondeT)) :: sondedT, sondedP, sondedTD, sondelogP
-  real, dimension(nx) :: tempd
-  real, dimension(ny) :: p
-  integer :: i, j, k, nt, vecx
-  real :: pdmax, pdmin
-  real :: dp, dpd, dt, dpv
-  real :: undeff
-  real, allocatable, dimension(:,:) :: u, v
-  real, allocatable, dimension(:) :: pv
-  integer, allocatable, dimension(:) :: interpo
-  logical :: heiopt_z, no_frame_flag
-
-  heiopt_z=.false.
-  nt=size(sondeT)
-
-  if(present(undef))then
-     undeff=undef
-  end if
-
-  if(present(vx))then
-     vecx=vx
-  else
-     vecx=10
-  end if
-
-!-- DCL 
-  call SGLSET('LCLIP',.true.)  ! åԥ󥰽
-
-!-- ʹ, ץ
-  if(present(viewx_int))then
-     vxmin=viewx_int(1)
-     vxmax=viewx_int(2)
-  else
-     vxmin=0.25
-     vxmax=0.75
-  end if
-
-  if(present(viewy_int))then
-     vymin=viewy_int(1)
-     vymax=viewy_int(2)
-  else
-     vymin=0.1
-     vymax=0.8
-  end if
-
-  if(present(no_frame))then
-     no_frame_flag=no_frame
-  else
-     no_frame_flag=.false.
-  end if
-
-!-- ֤ѿ֤
-  pmin=p_int(1)
-  pmax=p_int(2)
-  tmin=t_int(1)
-  tmax=t_int(2)
-
-  if(present(undef))then
-     undeff=undef
-  end if
-
-!-- DCL 
-  call SGLSET('LCLIP',.true.)  ! åԥ󥰽
-  call DclSetParm( 'ENABLE_CONTOUR_MESSAGE', .false. )
-
-  dt=(tmax-tmin)/(nx-1)
-  tempd=(/((tmin+dt*(i-1)),i=1,nx)/)
-  dp=(pmax-pmin)/(ny-1)
-  p=(/((pmax-dp*(i-1)),i=1,ny)/)
-
-  if(present(sondeZ))then
-     ! ٷ׻, z  p ľʤ pt η׻Բǽ (׽)
-     if(present(sondeZ))then
-        dpd=(pmax-pmin)/(ny-1)
-        pdmax=pmax
-        pdmin=pmin
-        heiopt_z=.true.
-     end if
-  else
-     pdmin=pmin*1.0e-2
-     pdmax=pmax*1.0e-2
-     dpd=(pdmax-pdmin)/(ny-1)
-  end if
-
-!-- ƶη׻
-  do j=1,ny
-     do i=1,nx
-        temp(i,j)=tempd(i)+slope*log(p(j)/p0)
-        pt(i,j)=theta_dry( temp(i,j), p(j) )
-        spt(i,j)=thetaes_Bolton( temp(i,j), p(j) )
-        qvs(i,j)=TP_2_qvs( temp(i,j), p(j) )*1.0e3
-     end do
-  end do
-
-  do j=1,nt
-     if(sondeT(j)==undeff.or.sondeP(j)==undeff.or.sondeQV(j)==undeff.or.sondeU(j)==undeff.or.sondeV(j)==undeff)then
-        sondedT(j)=undeff
-!        sondedP(j)=sondeP(j)*1.0e-2  ! 餯, ͤ undef ˤ DCL ǥ顼Ȥʤ
-        sondedTD(j)=undeff
-        sondelogP(j)=-log(sondeP(j))  ! 餯, ͤ undef ˤ DCL ǥ顼Ȥʤ
-     else
-        sondedT(j)=sondeT(j)-slope*log(sondeP(j)/p0)  ! temp, tempd Ʊ.
-!        sondedP(j)=sondeP(j)*1.0e-2
-        sondedTD(j)=es_TD(qvP_2_e(sondeQV(j),sondeP(j)))-slope*log(sondeP(j)/p0)
-        sondelogP(j)=-log(sondeP(j))
-     end if
-     if(heiopt_z.eqv..true.)then
-        sondedP(j)=sondeZ(j)
-     else
-        sondedP(j)=sondeP(j)*1.0e-2
-     end if
-  end do
-
-!-- ٥ȥδְ
-  allocate(pv(vecx))
-  allocate(interpo(vecx))
-  allocate(u(2,vecx))
-  allocate(v(2,vecx))
-  u(1,1:vecx)=0.0
-  v(1,1:vecx)=0.0
-  dpv=(pmax-pmin)/(vecx-1)
-  do i=1,vecx
-     pv(i)=-log(pmax-dpv*(i-1))  ! ٤Ȥ.
-     if(sondelogP(nt)>pv(i))then
-        call interpo_search_1d( sondelogP, pv(i), interpo(i), int(undeff) )
-
-        if(interpo(i)/=int(undeff))then
-           if(sondeU(interpo(i))/=undeff.and.sondeU(interpo(i)+1)/=undeff.and.  &
-  &           sondeV(interpo(i))/=undeff.and.sondeV(interpo(i)+1)/=undeff)then
-!        call interpolation_1d( sondeZ(interpo(i)), sondeZ(interpo(i)+1),  &
-!  &          sondeU(interpo(i)), sondeU(interpo(i)+1), pv(i), u(2,i))
-!        call interpolation_1d( sondelogP(interpo(i)), sondelogP(interpo(i)+1),  &
-!  &          sondeV(interpo(i)), sondeV(interpo(i)+1), pv(i), v(2,i))
-!write(*,*) sondeU(interpo(i)), sondeU(interpo(i)+1)
-! ϾΥȥȤΤ褦ޤΤ˷׻٤Ǥ뤬,
-! ǡ٤Ȥ, äȤᤤǶƤ褤Ȥ.
-              u(2,i)=sondeU(interpo(i))
-              v(2,i)=sondeV(interpo(i))
-           else
-              u(2,i)=undeff
-              v(2,i)=undeff
-           end if
-        else
-           u(2,i)=undeff
-           v(2,i)=undeff
-        end if
-     else
-        u(2,i)=undeff
-        v(2,i)=undeff
-     end if
-  end do
-
-  if(no_frame_flag.eqv..true.)then
-     call DclNewFig
-  else
-     call DclNewFrame
-  end if
-
   call DclScalingPoint( sondedT, sondedP )
   if(heiopt_z.eqv..true.)then
      call DclSetTransNumber( 1 )
@@ -446,6 +264,8 @@ subroutine SkewT_vec( title, slope, t_int, p_int,  &
   end if
 
   call DclDrawScaledAxis
+!  call DclDrawAxis( 'v', pdmax/40.0, pdmax/10.0, section=vxmin )
+!  call DclDrawAxis( 'v', pdmax/40.0, pdmax/10.0, section=vxmax )
 
   call UDISET('INDXMJ', 31)
   call UDISET('INDXMN', 31)
@@ -460,12 +280,187 @@ subroutine SkewT_vec( title, slope, t_int, p_int,  &
   call DclDrawContour( qvs )
   call DclDrawLine( sondedT, sondedP, index=43 )
   call DclDrawLine( sondedTD, sondedP, index=43, type=2 )
+  call DclDrawLine( sondedSEPT, sondedP, index=43, type=3 )
   call DclDrawTitle( 't', trim(title) )
 
-!-- DCL 
-  call SGLSET('LCLIP',.false.)  ! åԥ󥰽
+end subroutine
 
-  call GRFIG
+!-----------------------------------------------
+! ʲ, ñ̥٥ȥ뤬ʤХ
+
+subroutine axis_vec( p_int, vx, sondeP,  &
+  &                  sondeU, sondeV, sondeZ,  &
+  &                  view_int, vn, undef,  &
+  &                  unit_flag, unity, u_posi, uni_len )
+! skew-T  + vector ޤ롼
+! ȽļΥȥϤ٤ height  temperature Ǹ.
+  use Thermo_Const
+  use Thermo_Function
+  use Statistics
+  use Dcl
+  implicit none
+  real, intent(in) :: p_int(2)  ! ʵˤξü [Pa]
+                      ! p_int(1)=pmin, p_int(2)=pmax
+  real, intent(in) :: vx   !  vx ɸ.
+  real, intent(in), dimension(:) :: sondeP  ! Ǥε [Pa]
+  real, intent(in), dimension(size(sondeP)) :: sondeU  ! Ǥ [m/s]
+  real, intent(in), dimension(size(sondeP)) :: sondeV  ! Ǥ [m/s]
+  real, intent(in), dimension(size(sondeP)), optional :: sondeZ  ! Ǥι [m]
+  ! sondeP : logP ǽļȤ. ΤȤ, pmin, pmax, sondeP Ϥ٤
+  !               Pa ñ̤ǤȤ뤳.
+  ! sondeZ(optional) : geometric z ǽļȤ.
+  !              ΤȤ, pmin, pmax ϵǤϤʤ, 褷 [m] κǾͤͿ.
+  ! z=-logP δطˤʤ뤬, ǽΤ, ѼԤ
+  ! ˤ, min Ϻ, max Ϻͤ OK.
+  ! ǥեȤǤ, ǽļ.
+  real, intent(in), optional :: view_int(2)  ! viewport ξü.
+                                ! view_int(1)=vmin, view_int(2)=vmax
+                                ! ǥեȤ, (0.2, 0.8) Ǹ.
+  integer, intent(in), optional :: vn  ! ٥ȥδְʻҿ.
+  ! ְ, ɸ˴ؤʻҾ֤.
+  ! ǥեȤ 10 ʻ
+  real, intent(in), optional :: undef  ! ̤, ǥեȤǤꤷʤ.
+  logical, intent(in), optional :: unit_flag  ! ñ̥٥ȥ.
+                                ! default = .false. : ʤ.
+  real, intent(in), optional :: unity  ! unit_flag = .true. λ,
+                                ! ñ̥٥ȥ礭.
+                                ! ꤷʤ, 顼ǽλ.
+                                ! V ɸϤǤ 0.1 ǰ.
+  real, intent(in), optional :: u_posi(2)  ! ñ̥٥ȥθɸ (V ɸ).
+                                ! u_posi=(/vx,vy/)
+                                ! ꤷʤ, ü -0.1 ΤȤ.
+  real, intent(in), optional :: uni_len  ! ñ̥٥ȥĹ (V ɸ).
+                                ! default = 0.1
+
+!-- ʾ, 
+  real :: pmin  ! ļʵˤκ [Pa]
+  real :: pmax  ! ļʵˤκǹ [Pa]
+  real :: vmin  ! viewport  min.
+  real :: vmax  ! viewport  max.
+  logical :: u_flag
+!-- ʾ, ֤ѿ
+  real, dimension(size(sondeP)) :: sondedP, sondelogP
+  integer :: i, j, k, nt, vecx
+  real :: pdmax, pdmin, dpv
+  real :: undeff
+  real :: uvpx, uvpy, ulen
+  real, allocatable, dimension(:,:) :: u, v
+  real, allocatable, dimension(:) :: pv
+  integer, allocatable, dimension(:) :: interpo
+  logical :: heiopt_z, no_frame_flag
+
+  heiopt_z=.false.
+  nt=size(sondeP)
+
+  if(present(undef))then
+     undeff=undef
+  else
+     undeff=-999.0
+  end if
+
+  if(present(vn))then
+     vecx=vn
+  else
+     vecx=10
+  end if
+
+!-- ʹ, ץ
+  if(present(view_int))then
+     vmin=view_int(1)
+     vmax=view_int(2)
+  else
+     vmin=0.2
+     vmax=0.8
+  end if
+
+  if(present(unit_flag))then
+     u_flag=unit_flag
+
+     if(u_flag.eqv..true.)then
+        if(present(unity))then
+           write(*,*) "unity = ", unity
+        else
+           write(*,*) "*** ERROR (axis_vec) ***"
+           write(*,*) "unit_flag is true, so unity must be set."
+           write(*,*) "STOP."
+           stop
+        end if
+     end if
+  else
+     u_flag=.false.
+  end if
+
+  if(present(u_posi))then
+     uvpx=u_posi(1)
+     uvpy=u_posi(2)
+  else
+     uvpx=vx
+     uvpy=vmin-0.1
+  end if
+
+  if(present(uni_len))then
+     ulen=uni_len
+  else
+     ulen=0.1
+  end if
+
+!-- ֤ѿ֤
+  pmin=p_int(1)
+  pmax=p_int(2)
+
+  if(present(sondeZ))then
+     ! ٷ׻, z  p ľʤ pt η׻Բǽ (׽)
+     pdmax=pmax
+     pdmin=pmin
+     heiopt_z=.true.
+  else
+     pdmin=pmin*1.0e-2
+     pdmax=pmax*1.0e-2
+  end if
+
+  do j=1,nt
+     if(present(sondeZ))then
+        sondelogP(j)=sondeZ(j)  ! 餯, ͤ undef ˤ DCL ǥ顼Ȥʤ
+     else
+        sondelogP(j)=-log(sondeP(j))  ! 餯, ͤ undef ˤ DCL ǥ顼Ȥʤ
+     end if
+  end do
+
+!-- ٥ȥδְ
+  allocate(pv(vecx))
+  allocate(interpo(vecx))
+  allocate(u(2,vecx))
+  allocate(v(2,vecx))
+  u(1,1:vecx)=0.0
+  v(1,1:vecx)=0.0
+  dpv=(pmax-pmin)/(vecx-1)
+  do i=1,vecx
+     u(2,i)=undeff
+     v(2,i)=undeff
+     if(present(sondeZ))then
+        pv(i)=pmin+dpv*(i-1)  ! ٤Ȥ.
+     else
+        pv(i)=-log(pmax-dpv*(i-1))  ! ٤Ȥ.
+     end if
+     if(sondelogP(nt)>pv(i))then
+        call interpo_search_1d( sondelogP, pv(i), interpo(i), int(undeff) )
+
+        if(interpo(i)/=int(undeff))then
+           if(sondeU(interpo(i))/=undeff.and.sondeU(interpo(i)+1)/=undeff.and.  &
+  &           sondeV(interpo(i))/=undeff.and.sondeV(interpo(i)+1)/=undeff)then
+! ϾΥȥȤΤ褦ޤΤ˷׻٤Ǥ뤬,
+! ǡ٤Ȥ, äȤᤤǶƤ褤Ȥ.
+              u(2,i)=sondeU(interpo(i))
+              v(2,i)=sondeV(interpo(i))
+           end if
+        end if
+     end if
+  end do
+
+!-- DCL 
+!  call SGLSET('LCLIP',.false.)  ! åԥ󥰽
+
+  call DclNewFig
   if(heiopt_z.eqv..true.)then
      call DclSetTransNumber( 1 )
      call DclSetWindow( 0.0, 1.0, pdmin, pdmax )
@@ -473,20 +468,43 @@ subroutine SkewT_vec( title, slope, t_int, p_int,  &
      call DclSetTransNumber( 2 )
      call DclSetWindow( 0.0, 1.0, pdmax, pdmin )
   end if
-  call DclSetViewPort( vxmax, vxmax+0.1, vymin, vymax )
+  call DclSetViewPort( vx, vx+0.1, vmin, vmax )
   call DclSetTransFunction
 
   CALL UZLSET( 'LABELYR', .FALSE. )
   CALL UZLSET( 'LABELYL', .FALSE. )
 
-  call DclDrawAxis( 'v', pdmax/40.0, pdmax/10.0, section=vxmax+0.1 )
+  call DclDrawAxis( 'v', pdmax/40.0, pdmax/10.0, section=vx )
 
   call UGLSET( 'LMSG', .false. )
 
   call DclDrawVectors( u, v )
-write(*,*) u(2,:)
 
-end subroutine
+!-- ٥ȥ˴ؤ
+  if(u_flag.eqv..true.)then
+     call DclSetParm( 'VECTOR:LUMSG', .false. )
+     !-- ٥ȥ V ɸѴ
+     call DclSetParm( 'VECTOR:LNRMAL', .false. )
+     call DclSetParm( 'VECTOR:XFACT1', ulen/unity )
+     call DclSetParm( 'VECTOR:YFACT1', ulen/unity )
+     !-- ʲ, ñ̥٥ȥѥ롼Ȥ, ޤʤ.
+     !-- ñ̥٥ȥ.
+!     call DclSetParm( 'VECTOR:LUNIT', .true. )
+     !-- ñ̥٥ȥĹ, 踶.
+!     call DclSetParm( 'VECTOR:VXUNIT', ulen )
+!     call DclSetParm( 'VECTOR:VYUNIT', 0.0 )
+!     call DclSetParm( 'VECTOR:VXULOC', uvpx )
+!     call DclSetParm( 'VECTOR:VYULOC', uvpy )
+!     call DclSetUnitVectorTitle( 'X', 'U='//  &
+!  &       trim(adjustl(r2c_convert(unity,'(f6.2)')))//'m s|-1"' )
+     !-- Τ, ad hoc.
+     call DclDrawArrowNormalized( uvpx, uvpy, uvpx+ulen, uvpy, index=3 )
+     call DclDrawTextNormalized( uvpx+0.5*ulen, uvpy-0.025, 'U='//  &
+  &       trim(adjustl(r2c_convert(unity,'(f6.2)')))//'m s|-1"',  &
+  &       height=0.015, index=3 )
+  end if
+
+end subroutine axis_vec
 
 
 end module
